<p align="center">
  <br>中文 | <a href="README.en.md">English</a>
</p>

***

## 简介

xlconv 是一款转换工具，将excel转换为Json，支持同一工作簿管理多个Json和多类Json，支持各种数据类型、且数组和对象支持无限深度

## 安装

使用 pip 进行安装:

```
pip install xlconv
```
